#Function for ci's:
ci <- function (that_data){
  s <- sd(that_data)
  n <- length(that_data)
  error <- s/sqrt(n)
  crit_val <- abs(qt(.05/2, n-1))
  
  return(error*crit_val)
}


#Load libraries
library(dplyr)
library(ggplot2)
library(stringr)
library(lme4)

#Load data file:
my_data <- read.csv("experiment_data.csv", header = TRUE)

#Plot the data by trial type (like in the paper):
grouped_data <- group_by(my_data, `Pattern.Type`, `Trial.Type`)
summar_data <- summarize(grouped_data, mean(Correct), ci(Correct))
summar_data$`Trial.Type` <- gsub(" Forms", "", summar_data$`Trial.Type`)#Shorten variable names for readability
summar_data$`Trial.Type` <- factor(summar_data$`Trial.Type`, levels=c("Faithful",
                                                                            "Deleting",
                                                                            "Palatalizing",
                                                                            "Interacting")) #Order trials types
summar_data$Pattern.Type <- factor(summar_data$`Pattern.Type`, levels=c("Bleeding",
                                                                        "Feeding",
                                                                        "Counterbleeding",
                                                                        "Counterfeeding")) #Order patterns

#my_colors <- c("#ff9999","#cc99ff","cornflowerblue","white")#Color figure
my_colors <- c("grey48", "gray26", "grey82", "white") #B&W figure (in paper)
ggplot(summar_data, aes(x=`Trial.Type`, y=`mean(Correct)`, fill=`Pattern.Type`))+
  geom_col(position="dodge", color="black") +
  ylab("Proportion Correct") + 
  xlab("Trial Type") +
  ylim(c(0,1))+
  geom_segment(x=0, y=.5, xend=5, yend=.5, linetype=2)+
  scale_fill_manual(values=c(my_colors), name="Interaction Type")+
  geom_errorbar(mapping=aes(ymin=`mean(Correct)`- `ci(Correct)`, ymax=`mean(Correct)`+ `ci(Correct)`),
                width=.2,
                position=position_dodge(.9),
                alpha=1)+
  labs(title="Percent Correct in Testing by Pattern and Trial Type",
       subtitle="Error bars show 95% Confidence Intervals")


#Run the mixed effects model:
#Model with interactions included:
m_1 <- glmer(Correct ~ Transparent
            *Application
            *Deletion
            *Palatalization
            +(1|Subject)
            +(1|Stimulus),
            family = "binomial",
            glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 100000)),
            data = my_data)
summary(m_1)

#Find overall averages in each condition (for comparison with computational models):
overall_groups <- group_by(my_data, Pattern.Type, Trial.Type)
overall_summary <- summarize(overall_groups, mean(Correct))
